#
# spec file for package gmusicbrowser
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# gmusicbrowser has no external API.
%define __provides_exclude perl\\(.*\\)
Name:           gmusicbrowser
Version:        1.1.15
Release:        3.6
Summary:        Gtk2 jukebox for large music collections
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            http://gmusicbrowser.org/
Source:         http://gmusicbrowser.org/download/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gmusicbrowser-1.1.15-fix-perl-5.24.patch -- Fix an error with perl 5.24 (commit 853840e).
Patch0:         %{name}-1.1.15-fix-perl-5.24.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  perl
BuildRequires:  update-desktop-files
Requires:       typelib-1_0-Gst-1_0
Requires:       typelib-1_0-GstApp-1_0
Requires:       perl(Glib::Object::Introspection)
Requires:       perl(Gtk2)
Recommends:     %{name}-lang
Recommends:     perl(Gtk2::AppIndicator)
Recommends:     perl(Gtk2::Notify)
Recommends:     perl(Gtk2::WebKit)
Recommends:     perl(HTML::Parser)
Recommends:     perl(Locale::gettext)
Recommends:     perl(Net::DBus)
Suggests:       mpv
BuildArch:      noarch
%perl_requires

%description
Customisable jukebox based on Gtk2 for large music collections.

Main features:
 - Made with big libraries in mind.
 - Customisable window layouts.
 - Artist/album lock: restrict playlist to current artist/album.
 - Easy access to songs related to the currently playing song:
   * songs from the same album.
   * album(s) from the same artist(s).
   * songs with same title (other versions, covers, ...).
 - Supports Ogg Vorbis, MP3, FLAC files and other formats.
 - Simple mass-tagging and mass-renaming.
 - Notification icon, with a customisable tip window, which can be
   used to control the player.
 - Customisable SongTree widget for a pretty list of songs.
 - Support multiple genres for a song and multiple artists for each
   song by separating them.
 - Customisable labels can be set for each song (like bootleg,
   live, -'s favourites, ...).
 - Filters with unlimited nesting of conditions.
 - Customisable weighted random mode (based on rating, last time
   played, label, ...).
 - The possibility to act as a icecast server, to listen to your
   music remotely.
 - Plugins: nowplaying (external program song updates), last.fm,
   find pictures, simple lyrics, display Wikipedia artist page and
   search lyrics with Google.

%lang_package

%prep
%setup -q
%patch0 -p1

# Trim Unity actions.
lines=$(( $(grep -m1 -no '^Actions=' %{name}.desktop | sed 's/^\([[:digit:]]*\):.*$/\1/') - 1 ))
head -n $lines %{name}.desktop > %{name}.desktop.new
mv -f %{name}.desktop{.new,}

%build
# Nothing to build.

%install
%make_install \
  docdir=%{buildroot}%{_docdir}/%{name}

rm -f %{buildroot}%{_docdir}/%{name}/INSTALL
%suse_update_desktop_file -r -G %{name} %{name} AudioVideo Music
%fdupes %{buildroot}%{_datadir}
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/20x20/
%dir %{_datadir}/icons/hicolor/20x20/apps/
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Mon Sep 12 2016 sor.alexei@meowr.ru
- Trim "perl(*)" from automatic provides (boo#998293).
* Fri Jul 29 2016 sor.alexei@meowr.ru
- Add gmusicbrowser-1.1.15-fix-perl-5.24.patch from upstream: fix
  an error with perl 5.24 (commit 853840e).
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Update to 1.1.15:
  * Replace gmb icon with the svg icon made by zeltak.
  * Add mpv output.
  * Add "high priority" keyboard shortcuts.
  * Add embedded pictures tab to song property dialog.
  * When adding a song, check if it is already in the library with
    an old filename.
  * PictureBrowser: improve navigation of the folder pane.
  * PictureBrowser: add folder icons to folder pane.
  * PictureBrowser: keep scaled size constant when changing picture.
  * PictureBrowser: add "paste link" to context menu.
  * Activate "accent-insensitive" search on file, folder and comment
    fields.
  * Optimize function that remove "accents" (diacritic).
  * Add star pictures option for rating fields.
  * Add option for label-like and rating fields to have a submenu in
    song context menu.
  * Add option to show/hide extension to title_or_file field
    (defaults to hide).
  * Update Google image parser.
  * Various equalizer improvements.
  * Use internal equalizer presets rather than gstreamer's (with
    option to sync with gstreamer's).
  * MPlayer: use slave mode to improve the transition between
    songs.
  * Picture finder plugin: add DuckDuckGo search engine.
  * Add Shuffle command.
  * Use title_or_file instead of title for choose-songs menus.
  * Make middle-click on stop and quit button set the after queue
    action.
  * Make middle-click on Artist and Album Lock enqueue the artist
    or album.
  * Make filename sorting in PictureBrowser number-aware.
  * Add "Row number" column for SongList.
  * Add "Append to playlist" to song context menu when in list
    mode.
  * Show artist in addition to title in recent songs menu.
  * Fix setting master filter not working properly.
  * MPlayer: fix "Failed to open ~/.mplayer/input.conf" error.
  * Fix setting replaygain value with decimals not working with
    perl <5.20 when using locales that don't use dot as decimal
    separator.
  * Fix songs with no label/genre not matching negative label/genre
    filters.
  * Fix "0" appearing in "artists" tab for unknown artists.
  * LastFM plugin: give up sending now-playing when the song is no
    longer playing.
  * Update translations: Finnish, French, German, Korean,
    Malay (Malaysia).
- Suggest MPV.
* Fri Mar 20 2015 sor.alexei@meowr.ru
- Update to 1.1.14:
  * Add support for GStreamer 1.x and small GStreamer
    updates/improvements:
    + gstreamer-1.x requires Glib::Object::Introspection and
    GStreamer introspection data (Gst-1.0.typelib).
    + The option -nogst will now disable loading GStreamer entirely.
    + The option -gst has been replaced by -gst0 that can force the
    use of gstreamer-0.10 even if gstreamer-1.0 is found.
    + When using gstreamer-1.x, gmusicbrowser now ask the system
    to install missing plugins.
  * Add EqualizerPresets widget to change/edit equalizer presets
    (requires gstreamer-1.0):
    + Adds EqualizerPresets to the default Equalizer layout.
    + Also adds EqualizerPresetsSimple widget as an alias for
    EqualizerPresets(open=1,notoggle=1).
  * Add way to edit "persistent" labels, and dialog to rename
    labels.
  * Add "new label" entry to the "edit labels" submenu.
  * Make scroll wheel increase/decrease numbers in the search bar.
  * Add options to override default web browser and file browser.
  * Add thousand separators in most displayed numbers.
  * Various number-related improvements/fixes:
    + Show unit for bitrate and sampling rate.
    + The length field now uses multiple units.
    + More consistent size units.
    + Smarter parsing of units in search strings.
  * Fix auto-selected embedded pictures always showing the first
    picture (only fix newly autoselected pictures).
  * Translations updates: Finnish, French, German, Polish, Korean,
    Serbian.
  * New translations: Lithuanian, Malay (Malaysia).
- Remove gmusicbrowser-gstreamer1_x.patch: implemented upstream.
* Mon Feb 23 2015 sor.alexei@meowr.ru
- Add gmusicbrowser-gstreamer1_x.patch to add GStreamer 1.x support
  (backported from gmusicbrowser 1.1.14).
* Tue Nov 18 2014 sor.alexei@meowr.ru
- Initial build.
